// This is an input file for revealing an inconsistency in Doxygen's type matching
// 
// Sometimes Doxygen fails to link argument types to their definitions at certain places in the generated HTML.
// The presence of this bug is related to the usage of namespaces and maybe also to the usage of STL.
// However, in all tested cases the argument types were correctly linked to their definition from the included source code.
// 
// Below are several declarations of a "process" method with a comment about what is
// the problem in the generated HTML documentation.
// Uncomment one declaration at a time to get the corresponding result.

#include <string>
#include <vector>
#include <map>

namespace PP
{
  typedef std::map<int, std::string> IntToStringDict;
}

namespace KK
{
  typedef std::vector<std::string> StringVector;
}

// This fails to recognize the type IntToStringDict both in the function list and function documentation
using PP::IntToStringDict;
namespace MM
{
  void process(const string& s, IntToStringDict& d, const KK::StringVector& v);
}

// This fails to recognize the type IntToStringDict both in the function list and function documentation
//namespace MM
//{
//  using PP::IntToStringDict;
//  void process(const string& s, IntToStringDict& d, const KK::StringVector& v);
//}

// This fails to recognize the type IntToStringDict both in the function list and function documentation
//using PP::IntToStringDict;
//void process(const string& s, IntToStringDict& d, const KK::StringVector& v);

// This fails to recognize the IntToStringDict type in the function documentation section
// but recognizes it in the list of namespace functions
//namespace MM
//{
//  using namespace PP;
//  void process(const string& s, IntToStringDict& d, const KK::StringVector& v);
//}

// This produces a correct output
//using namespace PP;
//void process(const string& s, IntToStringDict& d, const KK::StringVector& v);

// This produces a correct output
//void process(const string& s, PP::IntToStringDict& d, const KK::StringVector& v);
